/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 2008, Nokia
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 */

#ifndef __TRACKER_EXTRACT_ALBUMART_H__
#define __TRACKER_EXTRACT_ALBUMART_H__

#include <glib.h>

G_BEGIN_DECLS

gboolean tracker_albumart_init     (void);
void     tracker_albumart_shutdown (void);
gboolean tracker_albumart_process  (const unsigned char *buffer,
                                    size_t               len,
                                    const gchar         *mime,
                                    const gchar         *artist,
                                    const gchar         *album,
                                    const gchar         *filename);

G_END_DECLS

#endif /* __TRACKER_MINER_EXTRACT_H__ */
